@@ -4,6 +4,8 @@ import re
 
 from oneparams.api.base import BaseApi
 from oneparams.utils import deemphasize
+from alive_progress import alive_bar
+from oneparams.config import config_bar
 
 
 class BaseDiff(BaseApi):
@@ -24,7 +26,8 @@ class BaseDiff(BaseApi):
                  url_delete: str = None,
                  key_active: str = None,
                  url_inactive: str = None,
-                 submodules: dict = None):
+                 submodules: dict = None,
+                 handle_errors: dict = {}):
         """
         Define todas as urls que serão usadas,
         e também as keys do nome e id
@@ -45,15 +48,16 @@ class BaseDiff(BaseApi):
         self.key_active = key_active
 
         self.__submodules = submodules
+        self.__handle_error = handle_errors
 
     def create(self, data: dict) -> int:
         """
-        Recebe um parâmetro com os dados (dict) que devem 
+        Recebe um parâmetro com os dados (dict) que devem
         ser adicionados ao sistema,
-        executa a requisição de criação, adiciona na listagem de items 
+        executa a requisição de criação, adiciona na listagem de items
         e por fim retorna o id do item criado
         """
-        if self.__url_create is None: 
+        if self.__url_create is None:
             return None
 
         print("creating {} {}".format(data[self.key_name], self.item_name))
@@ -70,7 +74,7 @@ class BaseDiff(BaseApi):
         data = dict com dados recebidos de forma externa \n
         response = resposta da requisição de self.create() \n
 
-        Depois que adicionar os dados a função deve retornar 
+        Depois que adicionar os dados a função deve retornar
         o id do item \n
 
         Essa função serve basicamente para ser reescrita,
@@ -108,10 +112,10 @@ class BaseDiff(BaseApi):
         """
         Retorna todos os items cadastrados no sistema \n
 
-        Essa função deve ser sempre reescrita para 
+        Essa função deve ser sempre reescrita para
         enviar os dados retornados para a variavel
         self.items,
-        infelizmente isso é necessario por não haver um 
+        infelizmente isso é necessário por não haver um
         padrão de retorno dos dados dentro da api
         """
         print("researching {}".format(self.item_name))
@@ -120,6 +124,50 @@ class BaseDiff(BaseApi):
 
         return json.loads(response.content)
 
+    def get_all_details(self, inactive: bool = False) -> None:
+        """Puxa da api os detalhamentos de todos os items
+
+        Essa função não retorna nada, apenas preenche a variavel
+        self.list_details com os dados dos items, isso é feito
+        unicamente com o proposito de otimizar algumas pesquisas
+
+        Os detalhes podem ser acessados através da função
+        self.details()
+
+        Argumentos:
+        inactive -- Caso seja True puxa dados de items inativos também
+        """
+        if self.__url_get_detail is None:
+            return False
+
+        if inactive:
+            all_ids = self.items
+        else:
+            all_ids = self.items_active()
+
+        config_bar()
+        with alive_bar(len(all_ids), title=f"Getting {self.item_name} details") as bar:
+            for id in all_ids:
+                self.details(id)
+                bar()
+
+    def items_active(self) -> dict:
+        """Retorna todos os items ativos"""
+        if self.key_active is None:
+            return self.items
+        return {key: item for (key, item) in self.items.items()
+                if item[self.key_active] == True}
+
+    def len(self, inactive: bool = True):
+        """Retorna a quantidade de items
+
+        Argumentos:
+        inactive -- Caso True considera os items inativos na contagem
+        """
+        if inactive:
+            return len(self.items)
+        return len(self.items_active())
+
     def equals(self, data: dict) -> bool:
         """
         verifica se os dados de item são iguais aos dados
@@ -151,7 +199,7 @@ class BaseDiff(BaseApi):
                 return key
         return 0
 
-    def search_item_by_name(self, nome: dict) -> int:
+    def search_item_by_name(self, nome: dict, inactive: bool = False) -> int:
         """
         Pesquisa por um nome (self.key_name) e retorna o Id (self.key_id),
         a pesquisa é feita ignorando o case das letras e os acentos,
@@ -161,18 +209,35 @@ class BaseDiff(BaseApi):
         a função retorna uma exception
         """
         nome = deemphasize(nome)
-        ids = []
-        for key, item in self.items.items():
-            nome_item = deemphasize(item[self.key_name])
-            if re.search(nome, nome_item):
-                ids.append(key)
+        name_striped = re.findall(r"[a-z]+", nome)
 
-        if len(ids) == 1:
-            return ids[0]
+        if inactive:
+            id_to_check = self.items
+        else:
+            id_to_check = self.items_active()
 
-        if len(ids) == 0:
+        for n in name_striped:
+            ids = []
+            for id in id_to_check:
+                nome_item = deemphasize(self.items[id][self.key_name])
+                if re.search(n, nome_item):
+                    ids.append(id)
+            id_to_check = ids
+
+        if len(id_to_check) == 1:
+            return id_to_check[0]
+
+        if len(id_to_check) == 0:
             raise ValueError("{} {} not found!".format(self.item_name, nome))
-        if len(ids) > 0:
+
+        if len(id_to_check) > 0:
+            second_ids = []
+            for id in id_to_check:
+                if nome == deemphasize(self.items[id][self.key_name]).strip():
+                    second_ids.append(id)
+            if len(second_ids) == 1:
+                return second_ids[0]
+
             raise ValueError("{} {} is duplicated!".format(
                 self.item_name, nome))
 
@@ -192,14 +257,14 @@ class BaseDiff(BaseApi):
 
             self.list_details[content[self.key_id]] = content
             return content
-        
+
         except AttributeError as e:
             sys.exit(e)
 
     def name_to_id(self, data: dict) -> dict:
         """
-        Recebe os dados em um dicionario, 
-        e transforma os valores dos campos especificados 
+        Recebe os dados em um dicionario,
+        e transforma os valores dos campos especificados
         no dict self.submodules em ids  \n
 
         Retorna um novo "data" com os valores
@@ -248,7 +313,7 @@ class BaseDiff(BaseApi):
             print("skiping {} {}".format(data[self.key_name],
                                          self.item_name))
 
-    def submodule_id(self, name) -> int:
+    def submodule_id(self, name: str) -> int:
         id = self.item_id({self.key_name: name})
         if id == 0:
             id = self.create({self.key_name: name})
@@ -256,42 +321,17 @@ class BaseDiff(BaseApi):
                 return id
             raise ValueError(f'{self.item_name} {name} not found!')
         return id
-            
 
-    def delete(self, data: dict) -> bool:
-        """
-        Delete um item recebido por parametro (data),
-        data tem que ter:
-        data = [
-            self.key_name: str,
-            self.key_id: int
-        ]
-        """
-        if self.__url_delete is None:
-            return False
+    def inactive(self, item_id: int) -> bool:
+        """ Inativa um item cadastrado
 
-        print("deleting {} {}".format(data[self.key_name], self.item_name))
-        response = super().delete("{}/{}".format(self.__url_delete,
-                                                 data[self.key_id]))
-
-        return self.status_ok(response, erro_exit=False)
-
-    def inactive(self, data: dict) -> bool:
-        """
-        Inativa um item que é recebido por 'data'
-        'data' deve ter:
-        data = [
-            self.key_name: str,
-            self.key_id: int
-        ]
-
-        Retorna um valor boleano informando se o item 
+        Retorna um valor boleano informando se o item
         foi inativado ou não
         """
         if self.__url_inactive is None:
             return False
 
-        data = self.details(data[self.key_id])
+        data = self.details(item_id)
         if not data[self.key_active]:
             return True
 
@@ -303,7 +343,7 @@ class BaseDiff(BaseApi):
                                            data[self.key_id]),
                             data=data)
 
-        if not self.status_ok(response, erro_exit=False):
+        if not self.status_ok(response):
             return False
 
         # atualizo o item na lista
@@ -311,24 +351,54 @@ class BaseDiff(BaseApi):
 
         return True
 
-    def delete_all(self) -> None:
-        """
-            Deletar ou inativar (se possivel)
-            todos os items em self.items
-        """
-        deleted = []
+    def delete(self, item_id: int) -> bool:
+        """Deleta um item
 
-        for key, item in self.items.items():
-            if self.delete(item):
-                deleted.append(key)
+        Caso não consiga deletar o item
+        tentara inativar o item
+
+        Retorna True caso consiga deletar ou
+        inativar o item
+        """
+        if self.__url_delete is None:
+            return False
+
+        try:
+            item = self.items[item_id]
+        except KeyError:
+            raise KeyError(f'Id {item_id} not found!')
+
+        print("deleting {} {}".format(item[self.key_name], self.item_name))
+        response = super().delete("{}/{}".format(self.__url_delete,
+                                                 item_id))
+
+        if not self.status_ok(response, erro_exit=False):
+            return self.inactive(item_id)
+
+        self.items.pop(item_id)
+        try:
+            self.list_details.pop(item_id)
+        except KeyError:
+            pass
+        except AttributeError:
+            pass
+        return True
+
+    def status_ok(self, response, erro_exit=True):
+        """
+        verifica se e requisição foi feita com sucesso (200),
+        por padrão se a requisição falhou o programa é encerrado,
+        é possível alterar isso com erro_exit=False
+        """
+        if not response.ok:
+            for error_key, message in self.__handle_error.items():
+                if f"b'{error_key}'" == str(response.content):
+                    print(message)
+                    break
             else:
-                self.inactive(item)
+                print(response.content)
 
-        for i in deleted:
-            self.items.pop(i)
-            try:
-                self.list_details.pop(i)
-            except KeyError:
-                pass
-            except AttributeError:
-                pass
+            if erro_exit:
+                sys.exit()
+            return False
+        return True
